SchemaSpy - Table gnss_data.public.ppp_soln

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.ppp_soln | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
NetworkCode | varchar | 2147483647 |  |  |  |  |
stations.NetworkCode | ppp_soln_NetworkName_StationCode_fkey R
rinex.NetworkCode | ppp_soln_NetworkCode_fkey R
StationCode | varchar | 2147483647 |  |  |  |  |
stations.StationCode | ppp_soln_NetworkName_StationCode_fkey R
rinex.StationCode | ppp_soln_NetworkCode_fkey R
X | numeric | 12,4 | √ |  | null |  |  |
Y | numeric | 12,4 | √ |  | null |  |  |
Z | numeric | 12,4 | √ |  | null |  |  |
Year | numeric | 131089 |  |  |  |  |
rinex.ObservationYear | ppp_soln_NetworkCode_fkey R
DOY | numeric | 131089 |  |  |  |  |
rinex.ObservationDOY | ppp_soln_NetworkCode_fkey R
ReferenceFrame | varchar | 20 |  |  |  |  |  |
sigmax | numeric | 131089 | √ |  | null |  |  |
sigmay | numeric | 131089 | √ |  | null |  |  |
sigmaz | numeric | 131089 | √ |  | null |  |  |
sigmaxy | numeric | 131089 | √ |  | null |  |  |
sigmaxz | numeric | 131089 | √ |  | null |  |  |
sigmayz | numeric | 131089 | √ |  | null |  |  |
Table contained 685,567 rows at Fri Jul 28 14:55 EDT 2017

Close relationships within one two degrees of separation: